Overview — py_dss_interface 1.0.1 documentation

# Overview

docs |
tests | |requires|
package |

py-dss-interface is a Windows Python package providing access to OpenDSS direct dll version of OpenDSS - Version 9.2.0.1 (64-bit build); License Status: Open and Version 9.2.0.1 (32-bit build); License Status: Open.

- Free software: MIT license

## Disclaimer

This Python Package is purely responsibility of Paulo Radatz and not his employer. Use this package at your own risk.

## Installation

    pip install py-dss-interface

## Documentation

You can access the documentation through:

1 - The Read the Docs.

https://py_dss_interface.readthedocs.io/

2 - Another good resource is the OpenDSS_Direct_DLL.pdf doc created by Davis Montenegro. The package has been done based on this documentation.

https://sourceforge.net/p/electricdss/code/HEAD/tree/trunk/Version8/Distrib/Doc/OpenDSS_Direct_DLL.pdf

## Thanks

I want to thank Ênio Viana and Rodolfo Pilar Londero for all their contribution to the new version of the tool.